#
# spec file for package mcjoin
#
# Copyright (c) 2022 SUSE LLC
# Copyright (c) 2018-2022, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           mcjoin
Version:        2.11
Release:        2.3
Summary:        IPv4 tool for verifying multicast connectivity
License:        ISC
Group:          Productivity/Networking/Diagnostic
URL:            https://github.com/troglobit/mcjoin
#Git-Clone:     https://github.com/troglobit/mcjoin.git
Source:         https://github.com/troglobit/%{name}/releases/download/v%{version}/%{name}-%{version}.tar.gz

%description
mcjoin can be used to join IPv4 multicast groups, display
progress as multicast packets are received, and also send
multicast packets on select groups.

mcjoin can help verify intended IGMP snooping functionality
in layer-2 bridges/switches, as well as test forwarding of
multicast in static or dynamic multicast routing setups.

%prep
%autosetup -p1

%build
%configure \
	--docdir=%{_docdir}/%{name} \
	%{nil}
%make_build

%install
%make_install
# installed via macro
rm %{buildroot}%{_docdir}/%{name}/LICENSE

%check
%make_build check

%files
%license LICENSE
%doc ChangeLog.md
%doc %{_docdir}/%{name}
%{_bindir}/mcjoin
%{_mandir}/man1/mcjoin.1%{?ext_man}

%changelog
* Mon Feb 26 2024 Andreas Stieger <andreas.stieger@gmx.de>
- move to bootstrapped tarball
* Sun Sep 18 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 2.11
  * Fix issue with spurious timer expiry on Aarch64 (Arm64)
  * Fix #26: sender takes 100%% CPU usage in daemon mode
- Update to version 2.10
  * Minor bug fixes, found by Coverity Scan
  * Fix #18: optional trailing group port arguments ip4/ip6.
  * Fix #19: setsid() problem causing mcjoin to exit when
    daemonized.
  * regression introduced in v2.7.
  * Fix #23: fix uptime display in old output mode.
  * Document alternative use-case.
* Fri Jan 15 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 2.9
  * Multiple viewing modes, including new stats and rate/bytes
    view. See help text for details.
  * Another presentation view, show rate/bytes + plotter.
  * Update plotter on timer, not input, we want to see the gaps.
  * Change style of headings from top style to pimctl/mroutectl
    style.
  * Improved viewing modes and plotter characters for
    dupes/delay/etc.
  * Improved column sizing for better use of whitespace in narrow
    ttys.
  * Show stats on exit.
  * Support for scrolling log up/down with PgUp/PgDn.
  * Support for displaying uptime, also shown on exit.
  * Support for generating duplicate frames, for testing purposes.
  * Support for toggling debug logs at runtime.
* Fri Jan  8 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 2.8
  * Detect a default interface even on systems without default
    route.
  * Support Ctrl-L to refresh a garbled display.
  * Support for a deadline timeout -W sec.
  * Support for redirecting output to a log file
    e.g. "mcjoin -l debug > file".
  * Document reverse path filtering in Linux.
  * Document how to test with older IGMP versions in Linux.
  * Fix resize glitch in plotter (new event based framework).
  * Fix TTY restore on abort or abnormal exit.
  * Fully restore support for old output, "-o".
* Tue Nov 10 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.7
  * New user interface, inspired by mtr. Easier to track multiple
    streams and spot gaps in real-time.
  * Adjust ulimit so we can open enough sockets to send/receive
    multicast.
  * Support for adjusting payload length, 42 -> 1648.
  * Support for adjusting packet send/poll rate.
  * Support for using old UI using -o flag.
  * Support any source port in (S,G) joins.
  * Greatly improved IPv6 support, portability and multiple groups.
  * Dropped -r SEC option, not needed anymore and was misleading.
  * Fix #8: Handle IPv6 being disabled, per group and per socket.
  * Fix #9: No feedback on receiver when using mcjoin as sender.
  * Fix #10: Calculate and show gaps in received groups.
* Thu Apr 23 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.6
  * Full IPv6 support, both send and join.
  * Increase MAX number of groups to join: 250 -> 2048
  * Relocate source code to src/ sub-directory
  * Add support for sending with/to IPv6 address/group
  * Update docs slightly
* Wed Feb 26 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.5
  * Replaced mutually exclusive options -q and -d with -l level.
    Default log level is notice, for true quiet mode, use -l none
  * Added new daemon mode, which makes mcjoin detach from its
    controlling terminal and run in the background, with all
    output except progress redirected to syslog
  * Fix possible file descriptor leak
  * Improve error detection if mcjoin cannot find a default
    interface, a valid (source) IP address, or anything else
    goes wrong
  * Add support for -w SEC, initial delay before actually
    starting. Useful if started very early in a system bootstrap
    before network has come up properly
- Update to version 2.4
  * Support for SSM (S,G) join, in addition to the existing
    ASM (*,G) join
  * Find interface bsaed on default route with best metric
  * Initial support for IPv6 (*,G) and (S,G) joins
* Thu Apr  4 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 2.3
  * Automatically detect default interface
  * Enable support for multiple mcjoin receivers on one host using
    the same destination (Internet) port
  * Fix #1: Receiver does not stop after count received packets
  * Avoid using GLIBC extension `__progname`
* Mon Jun 18 2018 mardnh@gmx.de
- Initial package, version 2.2
